@@ -4,9 +4,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-12-16'; # DATE
+our $DATE = '2023-01-14'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.046'; # VERSION
+our $VERSION = '0.047'; # VERSION
 
 use Regexp::Pattern::Perl::Module ();
 
@@ -125,7 +125,7 @@ Sah::Schema::perl::modname_with_optional_args - Perl module name (e.g. Foo::Bar)
 
 =head1 VERSION
 
-This document describes version 0.046 of Sah::Schema::perl::modname_with_optional_args (from Perl distribution Sah-Schemas-Perl), released on 2022-12-16.
+This document describes version 0.047 of Sah::Schema::perl::modname_with_optional_args (from Perl distribution Sah-Schemas-Perl), released on 2023-01-14.
 
 =head1 SYNOPSIS
 
@@ -169,12 +169,12 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = ["Foo"];
+ $data = "Foo::Bar=arg1,arg2";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = ["Foo","arg"];
- my $errmsg = $validator->($data); # => "\@[1]: Not of type array"
+ $data = ["Foo",["arg1","arg2"],{}];
+ my $errmsg = $validator->($data); # => "String is not a valid JSON: malformed JSON string, neither tag, array, object, number, string or atom, at character offset 0 (before \"Foo::Bar=arg1,arg2\") at (eval 3149) line 29.\n"
 
 Often a schema has coercion rule or default value, so after validation the
 validated value is different. To return the validated (set-as-default, coerced,
@@ -184,12 +184,12 @@ prefiltered) value:
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = ["Foo"];
- my $res = $validator->($data); # => ["",["Foo"]]
+ $data = "Foo::Bar=arg1,arg2";
+ my $res = $validator->($data); # => ["","Foo::Bar=arg1,arg2"]
  
  # a sample invalid data
- $data = ["Foo","arg"];
- my $res = $validator->($data); # => ["\@[1]: Not of type array",["Foo","arg"]]
+ $data = ["Foo",["arg1","arg2"],{}];
+ my $res = $validator->($data); # => ["String is not a valid JSON: malformed JSON string, neither tag, array, object, number, string or atom, at character offset 0 (before \"Foo::Bar=arg1,arg2\") at (eval 3169) line 29.\n",["Foo",["arg1","arg2"],{}]]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
@@ -315,7 +315,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2021, 2020, 2019, 2018, 2017, 2016 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2021, 2020, 2019, 2018, 2017, 2016 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
